# PulpOstreeClient::ContentObjectsApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**list**](ContentObjectsApi.md#list) | **GET** /pulp/api/v3/content/ostree/objects/ | List ostree objects
[**read**](ContentObjectsApi.md#read) | **GET** {ostree_ostree_object_href} | Inspect an ostree object



## list

> PaginatedostreeOstreeObjectResponseList list(opts)

List ostree objects

A ViewSet class for OSTree objects (e.g., dirtree, dirmeta, file).

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::ContentObjectsApi.new
opts = {
  checksum: 'checksum_example', # String | Filter results where checksum matches value
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `typ` - Typ * `-typ` - Typ (descending) * `checksum` - Checksum * `-checksum` - Checksum (descending) * `relative_path` - Relative path * `-relative_path` - Relative path (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List ostree objects
  result = api_instance.list(opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling ContentObjectsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **checksum** | **String**| Filter results where checksum matches value | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;upstream_id&#x60; - Upstream id * &#x60;-upstream_id&#x60; - Upstream id (descending) * &#x60;timestamp_of_interest&#x60; - Timestamp of interest * &#x60;-timestamp_of_interest&#x60; - Timestamp of interest (descending) * &#x60;typ&#x60; - Typ * &#x60;-typ&#x60; - Typ (descending) * &#x60;checksum&#x60; - Checksum * &#x60;-checksum&#x60; - Checksum (descending) * &#x60;relative_path&#x60; - Relative path * &#x60;-relative_path&#x60; - Relative path (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedostreeOstreeObjectResponseList**](PaginatedostreeOstreeObjectResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> OstreeOstreeObjectResponse read(ostree_ostree_object_href, opts)

Inspect an ostree object

A ViewSet class for OSTree objects (e.g., dirtree, dirmeta, file).

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::ContentObjectsApi.new
ostree_ostree_object_href = 'ostree_ostree_object_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect an ostree object
  result = api_instance.read(ostree_ostree_object_href, opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling ContentObjectsApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_object_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**OstreeOstreeObjectResponse**](OstreeOstreeObjectResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

